@@ -1,3 +1,12 @@
+//
+// Telescope - graphical task switcher
+//
+// (c) Ilya Skriblovsky, 2010
+// <Ilya.Skriblovsky@gmail.com>
+//
+
+// $Id: Main.cpp 95 2010-06-14 08:57:20Z mitrandir $
+
 #include <stdio.h>
 #include <stdlib.h>
 
@@ -6,6 +15,7 @@
 #include "TeleWindow.h"
 #include "XTools.h"
 #include "Settings.h"
+#include "Resources.h"
 
 int main(int argc, char *argv[])
 {
@@ -35,6 +45,8 @@ int main(int argc, char *argv[])
 
     XTools::enableCompositeRedirect();
 
+    Resources resources(dpy);
+
     TeleWindow *window = new TeleWindow(dpy);
     //window->show();
 
