@@ -5,7 +5,7 @@
 // <Ilya.Skriblovsky@gmail.com>
 //
 
-// $Id: TeleWindow.cpp 102 2010-06-29 13:20:56Z mitrandir $
+// $Id: TeleWindow.cpp 105 2010-07-06 10:59:53Z mitrandir $
 
 #include "TeleWindow.h"
 
@@ -126,7 +126,7 @@ TeleWindow::TeleWindow(Display *dpy)
 
 
     // Hotkey keycode
-    KeySym keysym = XStringToKeysym("F5");
+    KeySym keysym = XStringToKeysym(Settings::instance()->hotKey());
     _hotKeyCode = XKeysymToKeycode(_dpy, keysym);
     _hotKeyPressed = false;
 
@@ -397,7 +397,7 @@ void TeleWindow::eventLoop()
     XEvent event;
 
 
-    XGrabKey(_dpy, _hotKeyCode, AnyModifier, _rootWindow, False, GrabModeAsync, GrabModeAsync);
+    XGrabKey(_dpy, _hotKeyCode, 0, _rootWindow, False, GrabModeAsync, GrabModeAsync);
 
     _breakEventLoop = false;
     while (! _breakEventLoop)
